@@ -13,7 +13,6 @@ my $StartingOf = {
 my $MessagesOf = { 'mesgtoobig' => ['Mail size limit exceeded'] };
 
 # X-UI-Out-Filterresults: unknown:0;
-# sub headerlist  { return ['X-UI-Out-Filterresults'] }
 sub description { '1&1: http://www.1and1.de' }
 sub scan {
     # Detect an error from 1&1
@@ -36,7 +35,6 @@ sub scan {
     return undef unless $mhead->{'subject'} eq 'Mail delivery failed: returning message to sender';
 
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
-    my @hasdivided = split("\n", $$mbody);
     my $rfc822part = '';    # (String) message/rfc822-headers part
     my $rfc822list = [];    # (Array) Each line in message/rfc822 part string
     my $blanklines = 0;     # (Integer) The number of blank lines
@@ -44,7 +42,7 @@ sub scan {
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $v = undef;
 
-    for my $e ( @hasdivided ) {
+    for my $e ( split("\n", $$mbody) ) {
         # Read each line between the start of the message and the start of rfc822 part.
         unless( $readcursor ) {
             # Beginning of the bounce message or delivery status part
@@ -63,16 +61,15 @@ sub scan {
         }
 
         if( $readcursor & $Indicators->{'message-rfc822'} ) {
-            # After "message/rfc822"
+            # Inside of the original message part
             unless( length $e ) {
-                $blanklines++;
-                last if $blanklines > 1;
+                last if ++$blanklines > 1;
                 next;
             }
             push @$rfc822list, $e;
 
         } else {
-            # Before "message/rfc822"
+            # Error message part
             next unless $readcursor & $Indicators->{'deliverystatus'};
             next unless length $e;
 
@@ -104,7 +101,7 @@ sub scan {
                 # Get error message and append the error message strings
                 $v->{'diagnosis'} .= ' '.$e if $v->{'diagnosis'};
             }
-        } # End of if: rfc822
+        } # End of error message part
     }
     return undef unless $recipients;
 
