@@ -28,7 +28,7 @@ my $ReFailures = {
 };
 
 # X-Mailer: <SMTP32 v8.22>
-sub headerlist  { return ['X-Mailer'] }
+sub headerlist  { return ['x-mailer'] }
 sub description { 'IPSWITCH IMail Server' }
 sub scan {
     # Detect an error from IMailServer
@@ -53,7 +53,6 @@ sub scan {
     return undef unless $match;
 
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
-    my @hasdivided = split("\n", $$mbody);
     my $rfc822part = '';    # (String) message/rfc822-headers part
     my $rfc822list = [];    # (Array) Each line in message/rfc822 part string
     my $blanklines = 0;     # (Integer) The number of blank lines
@@ -61,7 +60,7 @@ sub scan {
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $v = undef;
 
-    for my $e ( @hasdivided ) {
+    for my $e ( split("\n", $$mbody) ) {
         # Read each line between the start of the message and the start of rfc822 part.
         unless( $readcursor ) {
             # Beginning of the bounce message or delivery status part
@@ -80,16 +79,15 @@ sub scan {
         }
 
         if( $readcursor & $Indicators->{'message-rfc822'} ) {
-            # After "message/rfc822"
+            # Inside of the original message part
             unless( length $e ) {
-                $blanklines++;
-                last if $blanklines > 1;
+                last if ++$blanklines > 1;
                 next;
             }
             push @$rfc822list, $e;
 
         } else {
-            # Before "message/rfc822"
+            # Error message part
             last if $readcursor & $Indicators->{'message-rfc822'};
 
             # Unknown user: kijitora@example.com
@@ -124,7 +122,7 @@ sub scan {
                 $v->{'alterrors'}  .= ' '.$e if $v->{'alterrors'};
                 $v->{'alterrors'}   = $e if index($e, $StartingOf->{'error'}->[0]) > -1;
             }
-        } # End of if: rfc822
+        } # End of error message part
     }
     return undef unless $recipients;
 
