@@ -20,11 +20,6 @@ sub adapt {
     return undef unless exists $argvs->{'email'};
     return undef unless Sisimai::RFC5322->is_emailaddress($argvs->{'email'});
 
-    require Sisimai::String;
-    require Sisimai::Address;
-    require Sisimai::SMTP::Reply;
-    require Sisimai::SMTP::Status;
-
     my $dscontents = undef;
     my $rfc822head = {};
     my $v = undef;
@@ -49,7 +44,7 @@ sub adapt {
         $dscontents = [__PACKAGE__->DELIVERYSTATUS];
         $v = $dscontents->[-1];
 
-        $v->{'date'}      = localtime(Sisimai::Time->new($argvs->{'timestamp'}));
+        $v->{'date'}      = gmtime(Sisimai::Time->new($argvs->{'timestamp'}));
         $v->{'agent'}     = __PACKAGE__->smtpagent;
         $v->{'lhost'}     = $argvs->{'ip'};
         $v->{'status'}    = $argvs->{'status'} || '';
@@ -73,8 +68,8 @@ sub adapt {
             $v->{'reason'} = 'feedback';
             $v->{'feedbacktype'} = 'abuse';
         }
-        $v->{'status'}    ||= Sisimai::SMTP::Status->find($v->{'diagnosis'});
-        $v->{'replycode'} ||= Sisimai::SMTP::Reply->find($v->{'diagnosis'});
+        $v->{'status'}    ||= Sisimai::SMTP::Status->find($v->{'diagnosis'}) || '';
+        $v->{'replycode'} ||= Sisimai::SMTP::Reply->find($v->{'diagnosis'})  || '';
 
         # Generate pseudo message/rfc822 part
         $rfc822head = {
@@ -106,8 +101,8 @@ sub adapt {
             $v->{'status'} = $statuscode;
         }
 
-        $v->{'status'}    ||= Sisimai::SMTP::Status->find($diagnostic);
-        $v->{'replycode'} ||= Sisimai::SMTP::Reply->find($diagnostic);
+        $v->{'status'}    ||= Sisimai::SMTP::Status->find($diagnostic) || '';
+        $v->{'replycode'} ||= Sisimai::SMTP::Reply->find($diagnostic)  || '';
         $v->{'diagnosis'}   = $argvs->{'reason'} || '';
         $v->{'agent'}       = __PACKAGE__->smtpagent;
 
