@@ -13,7 +13,8 @@ sub match {
     # @since v4.0.0
     my $class = shift;
     my $argv1 = shift // return undef;
-    my $index = [
+
+    state $index = [
         'account disabled temporarly for exceeding receiving limits',
         'account is exceeding their quota',
         'account is over quota',
@@ -59,7 +60,6 @@ sub match {
         'was automatically rejected: quota exceeded',
         'would be over the allowed quota',
     ];
-
     return 1 if grep { rindex($argv1, $_) > -1 } @$index;
     return 0;
 }
@@ -74,15 +74,13 @@ sub true {
     my $class = shift;
     my $argvs = shift // return undef;
 
-    return undef unless ref $argvs eq 'Sisimai::Data';
     return undef unless $argvs->deliverystatus;
     return 1 if $argvs->reason eq 'mailboxfull';
 
     # Delivery status code points "mailboxfull".
     # Status: 4.2.2
     # Diagnostic-Code: SMTP; 450 4.2.2 <***@example.jp>... Mailbox Full
-    require Sisimai::SMTP::Status;
-    return 1 if Sisimai::SMTP::Status->name($argvs->deliverystatus) eq 'mailboxfull';
+    return 1 if (Sisimai::SMTP::Status->name($argvs->deliverystatus) || '') eq 'mailboxfull';
 
     # Check the value of Diagnosic-Code: header with patterns
     return 1 if __PACKAGE__->match(lc $argvs->diagnosticcode);
