@@ -4,12 +4,12 @@ use strict;
 use warnings;
 
 my $RhostClass = {
-    qr/\Aaspmx[.]l[.]google[.]com\z/                 => 'GoogleApps',
-    qr/[.](?:prod|protection)[.]outlook[.]com\z/     => 'ExchangeOnline',
-    qr/\A(?:smtp|mailstore1)[.]secureserver[.]net\z/ => 'GoDaddy',
-    qr/\b(?:laposte[.]net|orange[.]fr)\z/            => 'FrancePTT',
-    qr/[.](?:ezweb[.]ne[.]jp|au[.]com)\z/            => 'KDDI',
-    qr/mx[0-9]+[.]qq[.]com\z/                        => 'TencentQQ',
+    qr/(?:aspmx|gmail-smtp-in)[.]l[.]google[.]com\z/  => 'GoogleApps',
+    qr/[.](?:prod|protection)[.]outlook[.]com\z/      => 'ExchangeOnline',
+    qr/\A(?:smtp|mailstore1)[.]secureserver[.]net\z/  => 'GoDaddy',
+    qr/\b(?>laposte[.]net|(?:orange|wanadoo)[.]fr)\z/ => 'FrancePTT',
+    qr/[.](?:ezweb[.]ne[.]jp|au[.]com)\z/             => 'KDDI',
+    qr/mx[0-9]+[.]qq[.]com\z/                         => 'TencentQQ',
 };
 
 sub list {
